==> nextcloud-21.0.0-9-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/gl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "A información da CPU non está dispoñíbel",
    "Load average" : "Carga media",
    "Last minute" : "Último minuto",
    "Memory info not available" : "A información da memoria non está dispoñíbel",
    "Total" : "Total",
    "Current usage" : "Uso actual",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Links" : "Ligazóns",
    "Mails" : "Correos",
    "Federated sent" : "Federados enviados",
    "Federated received" : "Federados recibidos",
    "Talk conversations" : "Conversas co Talk",
    "24 hours" : "24 horas",
    "1 hour" : "1 hora",
    "5 mins" : "5 minutos",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Non admitido!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Seguimento",
    "Monitoring app with useful server information" : "Aplicación de seguimento con información útil do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece información útil do servidor, como a carga da CPU, o uso da memoria RAM, o uso do disco, o número de usuarios, etc.",
    "Operating System" : "Sistema operativo",
    "CPU" : "CPU",
    "Memory" : "Memoria",
    "Server time" : "Hora do servidor",
    "Uptime" : "Tempo de actividade",
    "Load" : "Carga",
    "Disk" : "Disco",
    "Mount" : "Montaxe",
    "Filesystem" : "Sistema de ficheiros",
    "Size" : "Tamaño",
    "Available" : "Dispoñíbel",
    "Used" : "Usado",
    "You will get a notification once one of your disks is nearly full." : "Recibirá unha notificación cando un dos seus discos estea case completo.",
    "Files:" : "Ficheiros:",
    "Storages:" : "Almacenamentos:",
    "Free Space:" : "Espazo libre:",
    "Network" : "Rede",
    "Hostname" : "Nome de máquina",
    "DNS" : "DNS",
    "Gateway" : "Pasarela",
    "Status" : "Estado",
    "Speed" : "Velocidade",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Usuarios activos",
    "Total users:" : "Total de usuarios:",
    "Shares" : "Comparticións",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory Limit:" : "Límite de memoria:",
    "Max Execution Time:" : "Tempo máximo de execución:",
    "Upload max size:" : "Tamaño máximo de envío:",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "Size:" : "Tamaño:",
    "External monitoring tool" : "Ferramenta externa de supervisión",
    "You can connect an external monitoring tool by using this end point:" : "Pode conectar unha ferramenta externa de seguimento usando este punto final:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Engadindo «?format=json» na fin do URL devolve o resultado en JSON.",
    "Time Servers" : "Servidores de hora"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/gl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "A información da CPU non está dispoñíbel",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Links" : "Ligazóns",
    "Emails" : "Correos",
    "Federated sent" : "Federados enviados",
    "Federated received" : "Federados recibidos",
    "Talk conversations" : "Conversas co Talk",
    "24 hours" : "24 horas",
    "1 hour" : "1 hora",
    "5 mins" : "5 minutos",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Non admitido!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Seguimento",
    "Monitoring app with useful server information" : "Aplicación de seguimento con información útil do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece información útil do servidor, como a carga da CPU, o uso da memoria RAM, o uso do disco, o número de usuarios, etc.",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memoria",
    "Disk" : "Disco",
    "Size:" : "Tamaño:",
    "Used:" : "Usado:",
    "You will get a notification once one of your disks is nearly full." : "Recibirá unha notificación cando un dos seus discos estea case completo.",
    "Files:" : "Ficheiros:",
    "Storages:" : "Almacenamentos:",
    "Free Space:" : "Espazo libre:",
    "Network" : "Rede",
    "Hostname:" : "Nome de máquina:",
    "DNS:" : "DNS:",
    "Gateway:" : "Pasarela:",
    "Status:" : "Estado:",
    "Speed:" : "Velocidade:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuarios activos",
    "Total users:" : "Total de usuarios:",
    "Shares" : "Comparticións",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory limit:" : "Límite de memoria:",
    "Max execution time:" : "Tempo máximo de execución:",
    "Upload max size:" : "Tamaño máximo de envío:",
    "Extensions:" : "Extensións:",
    "Unable to list extensions" : "Non foi posíbel listar as extensións",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ferramenta externa de supervisión",
    "You can connect an external monitoring tool by using this end point:" : "Pode conectar unha ferramenta externa de seguimento usando este punto final:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Engadindo «?format=json» na fin do URL devolve o resultado en JSON.",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "A continuación, pase o testemuño coa cabeceira «Token NC» ao consultar o URL anterior.",
    "Operating System" : "Sistema operativo",
    "CPU" : "CPU",
    "Server time" : "Hora do servidor",
    "Uptime" : "Tempo de actividade",
    "Mount" : "Montaxe",
    "Filesystem" : "Sistema de ficheiros",
    "Size" : "Tamaño",
    "Available" : "Dispoñíbel",
    "Used" : "Usado",
    "Files" : "Ficheiros",
    "Hostname" : "Nome de máquina",
    "DNS" : "DNS",
    "Gateway" : "Pasarela",
    "Status" : "Estado",
    "Speed" : "Velocidade",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Version" : "Versión",
    "Type" : "Tipo"
},
"nplurals=2; plural=(n != 1);");
